import React from 'react';
import ReactDOM from 'react-dom';
import { interpolateYlOrRd, scaleSequential, scaleSqrt, max } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { useCodes } from './useCodes';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const selectedYear = "2017"

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const codes = useCodes();

  if (!worldAtlas || !data || !codes) {
    return <pre>Loading...</pre>;
  }
  
  console.log(codes);
  
  const numericCodeByAlphaCode = new Map();
  codes.forEach(code => {
    const alpha3Code = code["alpha-3"];
    const numericCode =  code["country-code"];
    numericCodeByAlphaCode.set(alpha3Code, numericCode);
  });
  
  const filteredData = data.filter(d => d.Year === selectedYear);
  
  const rowByNumericCode = new Map();
  filteredData.forEach(d => {
    const alpha3Code = d.Code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
  	rowByNumericCode.set(numericCode, d);
  })

  // console.log(rowByCountry);
  
  const colourValue = d => d.aids;
  
  const colourScale = scaleSequential(interpolateYlOrRd)
  	.domain([0, max(data, colourValue)])
  
  // console.log(sizeScale(max(data, sizeValue)))
  // console.log(max(data, sizeValue))
  // console.log(sizeValue(data[0]));

  return (
    <svg width={width} height={height}>
      <Marks 
        worldAtlas={worldAtlas} 
        rowByNumericCode={rowByNumericCode} 
        colourScale={colourScale}
        colourValue={colourValue}
        />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
